View Issue Details

IDProjectCategoryView StatusLast Update
0002777FSSCPBuild systempublic2013-01-13 09:13
Reporteronlyjob Assigned To 
PrioritylowSeveritytweakReproducibilityhave not tried
Status resolvedResolutionfixed 
Platformx86_64OSDebianOS Version7
Product Version3.6.14 
Summary0002777: spelling corrections [patch]
Descriptioncorrect grammar with patch.
TagsNo tags attached.

Activities

onlyjob

2013-01-10 05:30

reporter  

spelling.patch (24,187 bytes)   
Last-Update: 2012-12-27
Author: Dmitry Smirnov <onlyjob@member.fsf.org>
Forwarded: 2013-01-10
Description: spelling corrections

--- a/code/network/psnet2.cpp
+++ b/code/network/psnet2.cpp
@@ -2003,9 +2003,9 @@
 								Reliable_sockets[i].last_packet_received = psnet_get_time();
 								memcpy(&Reliable_sockets[i].addr,&rcv_addr,sizeof(SOCKADDR));
 								Reliable_sockets[i].status = RNF_LIMBO;
 								*socket = i;
-								ml_string("Succesfully connected to server in nw_ConnectToServer().");
+								ml_string("Successfully connected to server in nw_ConnectToServer().");
 								//Now send I_AM_HERE packet
 								conn_header.type = RNT_I_AM_HERE;
 								conn_header.seq = (ushort)(~CONNECTSEQ);
 								conn_header.data_len = 0;
--- a/code/autopilot/autopilot.cpp
+++ b/code/autopilot/autopilot.cpp
@@ -224,9 +224,9 @@
 // This does:
 //        * Control switched from player to AI
 //        * Time compression to 32x
 //        * Lock time compression -WMC
-//        * Tell AI to fly to targetted Nav Point (for all nav-status wings/ships)
+//        * Tell AI to fly to targeted Nav Point (for all nav-status wings/ships)
 //		  * Sets max waypoint speed to the best-speed of the slowest ship tagged
 bool StartAutopilot()
 {
 	// Check for support ship and dismiss it if it is not doing anything.
--- a/code/autopilot/autopilot.h
+++ b/code/autopilot/autopilot.h
@@ -82,9 +82,9 @@
 // This does:
 //        * Checks if Autopilot is allowed.  See CanAutopilot() for conditions.
 //        * Control switched from player to AI
 //        * Time compression to 32x
-//        * Tell AI to fly to targetted Nav Point (for all nav-status wings/ships)
+//        * Tell AI to fly to targeted Nav Point (for all nav-status wings/ships)
 //        * Sets max waypoint speed to the best-speed of the slowest ship tagged
 // Returns false if autopilot cannot be started. True otherwise.
 bool StartAutopilot();
 
--- a/code/parse/lua.cpp
+++ b/code/parse/lua.cpp
@@ -4421,9 +4421,9 @@
 
 	return ade_set_args(L, "o", l_Shields.Set(object_h(objh->objp)));
 }
 
-ADE_FUNC(getSignature, l_Object, NULL, "Gets the object's unique signature", "number", "Returns the objects unique numeric signature, or -1 if invalid. useful for creating a metadata sytem")
+ADE_FUNC(getSignature, l_Object, NULL, "Gets the object's unique signature", "number", "Returns the objects unique numeric signature, or -1 if invalid. useful for creating a metadata system")
 {
 	object_h *oh;
 	if(!ade_get_args(L, "o", l_Object.GetPtr(&oh)))
 		return ade_set_error(L, "i", -1);
@@ -5997,9 +5997,9 @@
 	return ade_set_args(L, "o", l_WeaponBankType.Set(ship_banktype_h(sso->objp, dst, SWH_SECONDARY)));
 }
 
 
-ADE_VIRTVAR(Target, l_Subsystem, "object", "Object targetted by this subsystem. If used to set a new target, AI targeting will be switched off.", "object", "Targeted object, or invalid object handle if subsystem handle is invalid")
+ADE_VIRTVAR(Target, l_Subsystem, "object", "Object targeted by this subsystem. If used to set a new target, AI targeting will be switched off.", "object", "Targeted object, or invalid object handle if subsystem handle is invalid")
 {
 	ship_subsys_h *sso;
 	object_h *objh;
 	if(!ade_get_args(L, "o|o", l_Subsystem.GetPtr(&sso), l_Object.GetPtr(&objh)))
--- a/code/fs2netd/fs2netd_client.cpp
+++ b/code/fs2netd/fs2netd_client.cpp
@@ -478,9 +478,9 @@
 			break;
 
 		default:
 			ml_string("FS2NetD ERROR: Unknown return case for GetPlayerData()");
-			strcpy_s(error_str, "Unkown return case from GetPlayerData(). Contact the FS2NetD Administrator!");
+			strcpy_s(error_str, "Unknown return case from GetPlayerData(). Contact the FS2NetD Administrator!");
 			retval = false;
 			break;
 	}
 
--- a/code/localization/localize.cpp
+++ b/code/localization/localize.cpp
@@ -1106,9 +1106,9 @@
 	}
 
 	// if we didn't find the language specified, error
 	if(found_start <= 0){
-		error_display(0, "Could not find specified langauge in tstrings.tbl!\n");
+		error_display(0, "Could not find specified language in tstrings.tbl!\n");
 		lcl_ext_close();
 		return;
 	}
 
--- a/code/ai/aiturret.cpp
+++ b/code/ai/aiturret.cpp
@@ -1355,9 +1355,9 @@
 }
 
 // NOTE:  Do not change this value unless you understand exactly what it means and what it does.
 //        It refers to how many (non-destroyed) subsystems (and turrets) will be scanned for possible
-//        targetting, per turret, per frame.  A higher value will process more systems at once,
+//        targeting, per turret, per frame.  A higher value will process more systems at once,
 //        but it will be much slower to scan though them.  It is not necessary to scan all
 //        non-destroyed subsystem each frame for each turret.  Also, "aifft_max_checks" is balanced
 //        against the original value, be sure to account for this discrepancy with any changes.
 #define MAX_AIFFT_TURRETS			60
--- a/code/cmdline/cmdline.cpp
+++ b/code/cmdline/cmdline.cpp
@@ -308,9 +308,9 @@
 int Cmdline_no_vsync = 0;
 
 // HUD related
 cmdline_parm ballistic_gauge("-ballistic_gauge", NULL);	// Cmdline_ballistic_gauge
-cmdline_parm dualscanlines_arg("-dualscanlines", NULL); // Cmdline_dualscanlines  -- Change to phreaks options including new targetting code
+cmdline_parm dualscanlines_arg("-dualscanlines", NULL); // Cmdline_dualscanlines  -- Change to phreaks options including new targeting code
 cmdline_parm orb_radar("-orbradar", NULL);			// Cmdline_orb_radar
 cmdline_parm rearm_timer_arg("-rearm_timer", NULL);	// Cmdline_rearm_timer
 cmdline_parm targetinfo_arg("-targetinfo", NULL);	// Cmdline_targetinfo  -- Adds ship name/class to right of target box -C
 
--- a/code/hud/hud.cpp
+++ b/code/hud/hud.cpp
@@ -1602,9 +1602,9 @@
 
 	// process asteroid brackets if necessary
 	hud_show_asteroid_brackets();
 
-	// process targetting data around the current target
+	// process targeting data around the current target
 	hud_show_targeting_gauges(frametime);
 
 	// process brackets and distance to remote detonate missile
 	hud_process_remote_detonate_missile();
--- a/code/hud/hudtarget.cpp
+++ b/code/hud/hudtarget.cpp
@@ -45,9 +45,9 @@
 #include "network/multi.h"
 #include "graphics/font.h"
 #include "network/multiutil.h"
 
-// If any of these bits in the ship->flags are set, ignore this ship when targetting
+// If any of these bits in the ship->flags are set, ignore this ship when targeting
 int TARGET_SHIP_IGNORE_FLAGS = (SF_EXPLODED|SF_DEPART_WARP|SF_DYING|SF_ARRIVING_STAGE_1|SF_HIDDEN_FROM_SENSORS);
 
 // Global values for the target bracket width and height, used for debugging
 int Hud_target_w, Hud_target_h;
@@ -1857,9 +1857,9 @@
 	}
 }
 
 
-// Given that object 'targeter' is targetting object 'targetee', 
+// Given that object 'targeter' is targeting object 'targetee', 
 // how far are they?   This uses the point closest to the targeter
 // object on the targetee's bounding box.  So if targeter is inside
 // targtee's bounding box, the distance is 0.
 float hud_find_target_distance( object *targetee, object *targeter )
@@ -2029,9 +2029,9 @@
 			}
 		}
 	}
 
-	// If no turret is attacking, check if objp is actually targetting attacked_objnum
+	// If no turret is attacking, check if objp is actually targeting attacked_objnum
 	// don't bail if targeting is for player
 	if ( !targeting_player && !turret_is_attacking ) {
 		ai_info *aip = &Ai_info[esct->shipp->ai_index];
 
@@ -3688,9 +3688,9 @@
 
 	// first render the current target the player has selected.
 	renderLeadCurrentTarget();
 
-	// if extra targetting info is enabled, render lead indicators for objects in the target display list.
+	// if extra targeting info is enabled, render lead indicators for objects in the target display list.
 	for(size_t i = 0; i < target_display_list.size(); i++) {
 		if ( (target_display_list[i].flags & TARGET_DISPLAY_LEAD) && target_display_list[i].objp ) {
 
 			// set the color
--- a/code/network/multimsgs.cpp
+++ b/code/network/multimsgs.cpp
@@ -2811,9 +2811,9 @@
 			if (objp->type == OBJ_SHIP) {
 				ship_actually_depart(objp->instance, s_method); 
 			}
 			else {
-				nprintf(("network", "Can not proces ship depart packed. Object with net signature %d is not a ship!\n", signature ));	
+				nprintf(("network", "Can not process ship depart packed. Object with net signature %d is not a ship!\n", signature ));	
 				return;
 			}
 			break;
 
@@ -4347,9 +4347,9 @@
 	}
 
 	// if this player is not allowed to do messaging, quit here
 	if( !multi_can_message(&Net_players[player_num]) ){
-		nprintf(("Network","Recieved player order packet from player not allowed to give orders!!\n"));
+		nprintf(("Network","Received player order packet from player not allowed to give orders!!\n"));
 		return;
 	}
 
 	// check to see if the type of order is a reinforcement call.  If so, intercept it, and
--- a/code/ship/ship.h
+++ b/code/ship/ship.h
@@ -455,9 +455,9 @@
 #define SF2_NO_ETS							(1<<21)		// The E - This ship does not have an ETS
 #define SF2_CLOAKED							(1<<22)		// The E - This ship will not be rendered
 #define SF2_NO_THRUSTERS					(1<<23)		// The E - Thrusters on this ship are not rendered.
 
-// If any of these bits in the ship->flags are set, ignore this ship when targetting
+// If any of these bits in the ship->flags are set, ignore this ship when targeting
 extern int TARGET_SHIP_IGNORE_FLAGS;
 
 #define MAX_DAMAGE_SLOTS	32
 #define MAX_SHIP_ARCS		2		// How many "arcs" can be active at once... Must be less than MAX_ARC_EFFECTS in model.h. 
--- a/code/weapon/weapons.cpp
+++ b/code/weapon/weapons.cpp
@@ -2343,9 +2343,9 @@
 						wip->particle_spewers[spew_index].particle_spew_type = PSPEW_PLUME;
 					} else {
 						wip->particle_spewers[spew_index].particle_spew_type = PSPEW_DEFAULT;
 					}
-				// for compatability with existing tables that dont have a type tag
+				// for compatability with existing tables that don't have a type tag
 				} else if (wip->particle_spewers[spew_index].particle_spew_type == PSPEW_NONE) { // make sure the ommission of type wanst to edit an existing entry
 					wip->particle_spewers[spew_index].particle_spew_type = PSPEW_DEFAULT;
 				}
 
@@ -6219,9 +6219,9 @@
 				// reset the timestamp
 				wp->particle_spew_time[psi] = timestamp(wip->particle_spewers[0].particle_spew_time);
 
 				// turn normals and origins to world space if we need to
-				if (!vm_vec_same(&wip->particle_spewers[psi].particle_spew_offset, &vmd_zero_vector)) {	// dont xform unused vectors
+				if (!vm_vec_same(&wip->particle_spewers[psi].particle_spew_offset, &vmd_zero_vector)) {	// don't xform unused vectors
 					vm_vec_unrotate(&spawn_pos, &wip->particle_spewers[psi].particle_spew_offset, &obj->orient);
 				} else {
 					spawn_pos = vmd_zero_vector;
 				}
@@ -6334,9 +6334,9 @@
 						// create a random unit vector and scale it
 						vm_vec_rand_vec_quick(&input_vel);
 						vm_vec_scale(&input_vel, wip->particle_spewers[psi].particle_spew_scale);
 						
-						if (wip->particle_spewers[psi].particle_spew_z_scale != 1.0f) {	// dont do the extra math for spherical effect
+						if (wip->particle_spewers[psi].particle_spew_z_scale != 1.0f) {	// don't do the extra math for spherical effect
 							temp_vel = input_vel;
 							temp_vel.xyz.z *= wip->particle_spewers[psi].particle_spew_z_scale;	// for an oviod particle effect to better combine with laser effects
 							vm_vec_unrotate(&input_vel, &temp_vel, &obj->orient);				// so it has to be rotated
 						}
--- a/code/freespace2/freespace.cpp
+++ b/code/freespace2/freespace.cpp
@@ -2525,9 +2525,9 @@
 
 		if (g3_in_frame() == 0) {
 			// Ensure that the bars are black
 			gr_set_color(0,0,0);
-			gr_set_bitmap(0); // Valathil - Dont ask me why this has to be here but otherwise the black bars dont draw
+			gr_set_bitmap(0); // Valathil - Don't ask me why this has to be here but otherwise the black bars don't draw
 			gr_rect(0, 0, gr_screen.max_w, yborder, false);
 			gr_rect(0, gr_screen.max_h-yborder, gr_screen.max_w, yborder, false);
 		} else {
 			//	Numeric constants encouraged by J "pig farmer" S, who shall remain semi-anonymous.
@@ -4266,9 +4266,9 @@
 
 		if (g3_in_frame() == 0) {
 			//Set rectangles
 			gr_set_color(0,0,0);
-			gr_set_bitmap(0); // Valathil - Dont ask me why this has to be here but otherwise the black bars dont draw
+			gr_set_bitmap(0); // Valathil - Don't ask me why this has to be here but otherwise the black bars don't draw
 			gr_rect(0, 0, gr_screen.max_w, yborder, false);
 			gr_rect(0, gr_screen.max_h-yborder, gr_screen.max_w, yborder, false);
 		} else {
 			//Set clipping
@@ -4281,9 +4281,9 @@
 		int yborder = gr_screen.max_h/CUTSCENE_BAR_DIVISOR;
 
 		if (g3_in_frame() == 0) {
 			gr_set_color(0,0,0);
-			gr_set_bitmap(0); // Valathil - Dont ask me why this has to be here but otherwise the black bars dont draw
+			gr_set_bitmap(0); // Valathil - Don't ask me why this has to be here but otherwise the black bars don't draw
 			gr_rect(0, 0, gr_screen.max_w, yborder, false);
 			gr_rect(0, gr_screen.max_h-yborder, gr_screen.max_w, yborder, false);
 		} else {
 			gr_reset_clip();
--- a/code/missionui/missionscreencommon.cpp
+++ b/code/missionui/missionscreencommon.cpp
@@ -1600,9 +1600,9 @@
 			g3_draw_htl_line(&start,&stop);
 		}
 		g3_done_instance(true);
 
-		gr_zbuffer_set(false); // Turn of Depthbuffer so we dont get gridlines over the ship or a disappearing scanline 
+		gr_zbuffer_set(false); // Turn of Depthbuffer so we don't get gridlines over the ship or a disappearing scanline 
 		if (time >= 0.5f) { // Phase 1 onward draw the grid
 			int i;
 			start.xyz.y = -offset;
 			start.xyz.z = size+offset*0.5f;
--- a/code/sound/ds.cpp
+++ b/code/sound/ds.cpp
@@ -300,9 +300,9 @@
 				ogg_int64_t pcm_total_size = ov_pcm_total(ovf, -1);
 				if (pcm_total_size > 0) {
 					*dest_size = (uint)(pcm_total_size * (*header)->nBlockAlign);
 				} else {
-					nprintf(("Sound", "SOUND ==> Size returned for this file is invalid. Please reencode the file, as it will not work correctly.\n"));
+					nprintf(("Sound", "SOUND ==> Size returned for this file is invalid. Please re-encode the file, as it will not work correctly.\n"));
 					return -1;
 				}
 			} else {
 				Assert( 0 );
--- a/code/ship/ship.cpp
+++ b/code/ship/ship.cpp
@@ -278,9 +278,9 @@
 	{ "no type",					SIF_NO_SHIP_TYPE,			0 },
 	{ "ship copy",					SIF_SHIP_COPY,				0 },
 	{ "in tech database",			SIF_IN_TECH_DATABASE | SIF_IN_TECH_DATABASE_M,	0 },
 	{ "in tech database multi",		SIF_IN_TECH_DATABASE_M,		0 },
-	{ "dont collide invisible",		SIF_SHIP_CLASS_DONT_COLLIDE_INVIS,	0 },
+	{ "don't collide invisible",		SIF_SHIP_CLASS_DONT_COLLIDE_INVIS,	0 },
 	{ "big damage",					SIF_BIG_DAMAGE,				0 },
 	{ "corvette",					SIF_CORVETTE,				0 },
 	{ "gas miner",					SIF_GAS_MINER,				0 },
 	{ "awacs",						SIF_AWACS,					0 },
spelling.patch (24,187 bytes)   

Eli2

2013-01-10 20:08

developer   ~0014625

Last edited: 2013-01-10 20:08

the change to ship.cpp will break Ships.tbl, see

http://www.hard-light.net/wiki/index.php/Ships.tbl#.22dont_collide_invisible.22

chief1983

2013-01-10 20:34

administrator   ~0014627

Yeah, that last one cannot go in. In fact I don't even know if any flag like that could support having an apostrophe. Rest of the patch looked fine though.

Goober5000

2013-01-12 22:06

administrator   ~0014639

Looks good to me too. I went to commit the patch, sans the ship.cpp change, but almost every patch hunk was rejected. Onlyjob, could you generate a new patch?

chief1983

2013-01-12 23:58

administrator   ~0014643

Against the latest trunk, please.

onlyjob

2013-01-13 08:17

reporter  

spelling[trunk].patch (26,295 bytes)   
Last-Update: 2013-01-13
Author: Dmitry Smirnov <onlyjob@member.fsf.org>
Forwarded: 2013-01-10
Bug-Upstream: http://scp.indiegames.us/mantis/view.php?id=2777
Description: spelling corrections

--- a/code/network/psnet2.cpp
+++ b/code/network/psnet2.cpp
@@ -1997,9 +1997,9 @@
 								Reliable_sockets[i].last_packet_received = psnet_get_time();
 								memcpy(&Reliable_sockets[i].addr,&rcv_addr,sizeof(SOCKADDR));
 								Reliable_sockets[i].status = RNF_LIMBO;
 								*socket = i;
-								ml_string("Succesfully connected to server in nw_ConnectToServer().");
+								ml_string("Successfully connected to server in nw_ConnectToServer().");
 								//Now send I_AM_HERE packet
 								conn_header.type = RNT_I_AM_HERE;
 								conn_header.seq = (ushort)(~CONNECTSEQ);
 								conn_header.data_len = 0;
--- a/code/autopilot/autopilot.cpp
+++ b/code/autopilot/autopilot.cpp
@@ -224,9 +224,9 @@
 // This does:
 //        * Control switched from player to AI
 //        * Time compression to 32x
 //        * Lock time compression -WMC
-//        * Tell AI to fly to targetted Nav Point (for all nav-status wings/ships)
+//        * Tell AI to fly to targeted Nav Point (for all nav-status wings/ships)
 //		  * Sets max waypoint speed to the best-speed of the slowest ship tagged
 bool StartAutopilot()
 {
 	// Check for support ship and dismiss it if it is not doing anything.
--- a/code/autopilot/autopilot.h
+++ b/code/autopilot/autopilot.h
@@ -82,9 +82,9 @@
 // This does:
 //        * Checks if Autopilot is allowed.  See CanAutopilot() for conditions.
 //        * Control switched from player to AI
 //        * Time compression to 32x
-//        * Tell AI to fly to targetted Nav Point (for all nav-status wings/ships)
+//        * Tell AI to fly to targeted Nav Point (for all nav-status wings/ships)
 //        * Sets max waypoint speed to the best-speed of the slowest ship tagged
 // Returns false if autopilot cannot be started. True otherwise.
 bool StartAutopilot();
 
--- a/code/parse/lua.cpp
+++ b/code/parse/lua.cpp
@@ -4911,9 +4911,9 @@
 
 	return ade_set_args(L, "o", l_Shields.Set(object_h(objh->objp)));
 }
 
-ADE_FUNC(getSignature, l_Object, NULL, "Gets the object's unique signature", "number", "Returns the objects unique numeric signature, or -1 if invalid. useful for creating a metadata sytem")
+ADE_FUNC(getSignature, l_Object, NULL, "Gets the object's unique signature", "number", "Returns the objects unique numeric signature, or -1 if invalid. useful for creating a metadata system")
 {
 	object_h *oh;
 	if(!ade_get_args(L, "o", l_Object.GetPtr(&oh)))
 		return ade_set_error(L, "i", -1);
@@ -5547,9 +5547,9 @@
 
 		return true;
 	}
 };
-ade_obj<cockpit_displays_info_h> l_CockpitDisplayInfos("cockpitdisplays", "Array of cockpit display informations");
+ade_obj<cockpit_displays_info_h> l_CockpitDisplayInfos("cockpitdisplays", "Array of cockpit display information");
 
 ADE_FUNC(__len, l_CockpitDisplayInfos, NULL, "Number of cockpit displays for this ship class", "number", "number of cockpit displays or -1 on error")
 {
 	cockpit_displays_info_h *cdih = NULL;
@@ -5951,9 +5951,9 @@
 
 	return ade_set_args(L, "o", l_Model.Set(model_h(sip->cockpit_model_num)));
 }
 
-ADE_VIRTVAR(CockpitDisplays, l_Shipclass, "cockpitdisplays", "Gets the cockpit display information array of this ship class", "cockpitdisplays", "Array handle containing the informations or invalid handle on error")
+ADE_VIRTVAR(CockpitDisplays, l_Shipclass, "cockpitdisplays", "Gets the cockpit display information array of this ship class", "cockpitdisplays", "Array handle containing the information or invalid handle on error")
 {
 	int ship_info_idx=-1;
 	cockpit_displays_info_h *cdih = NULL;
 	if(!ade_get_args(L, "o|o", l_Shipclass.Get(&ship_info_idx), l_CockpitDisplayInfos.GetPtr(&cdih)))
@@ -7087,9 +7087,9 @@
 	return ade_set_args(L, "o", l_WeaponBankType.Set(ship_banktype_h(sso->objp, dst, SWH_SECONDARY)));
 }
 
 
-ADE_VIRTVAR(Target, l_Subsystem, "object", "Object targetted by this subsystem. If used to set a new target, AI targeting will be switched off.", "object", "Targeted object, or invalid object handle if subsystem handle is invalid")
+ADE_VIRTVAR(Target, l_Subsystem, "object", "Object targeted by this subsystem. If used to set a new target, AI targeting will be switched off.", "object", "Targeted object, or invalid object handle if subsystem handle is invalid")
 {
 	ship_subsys_h *sso;
 	object_h *objh;
 	if(!ade_get_args(L, "o|o", l_Subsystem.GetPtr(&sso), l_Object.GetPtr(&objh)))
--- a/code/fs2netd/fs2netd_client.cpp
+++ b/code/fs2netd/fs2netd_client.cpp
@@ -489,9 +489,9 @@
 			break;
 
 		default:
 			ml_string("FS2NetD ERROR: Unknown return case for GetPlayerData()");
-			strcpy_s(error_str, "Unkown return case from GetPlayerData(). Contact the FS2NetD Administrator!");
+			strcpy_s(error_str, "Unknown return case from GetPlayerData(). Contact the FS2NetD Administrator!");
 			retval = false;
 			break;
 	}
 
--- a/code/localization/localize.cpp
+++ b/code/localization/localize.cpp
@@ -1297,9 +1297,9 @@
 	}
 
 	// if we didn't find the language specified, error
 	if(found_start <= 0){
-		error_display(0, "Could not find specified langauge in tstrings.tbl!\n");
+		error_display(0, "Could not find specified language in tstrings.tbl!\n");
 		lcl_ext_close();
 		return;
 	}
 
--- a/code/ai/aiturret.cpp
+++ b/code/ai/aiturret.cpp
@@ -1437,9 +1437,9 @@
 }
 
 // NOTE:  Do not change this value unless you understand exactly what it means and what it does.
 //        It refers to how many (non-destroyed) subsystems (and turrets) will be scanned for possible
-//        targetting, per turret, per frame.  A higher value will process more systems at once,
+//        targeting, per turret, per frame.  A higher value will process more systems at once,
 //        but it will be much slower to scan though them.  It is not necessary to scan all
 //        non-destroyed subsystem each frame for each turret.  Also, "aifft_max_checks" is balanced
 //        against the original value, be sure to account for this discrepancy with any changes.
 #define MAX_AIFFT_TURRETS			60
--- a/code/cmdline/cmdline.cpp
+++ b/code/cmdline/cmdline.cpp
@@ -309,9 +309,9 @@
 int Cmdline_no_vsync = 0;
 
 // HUD related
 cmdline_parm ballistic_gauge("-ballistic_gauge", NULL);	// Cmdline_ballistic_gauge
-cmdline_parm dualscanlines_arg("-dualscanlines", NULL); // Cmdline_dualscanlines  -- Change to phreaks options including new targetting code
+cmdline_parm dualscanlines_arg("-dualscanlines", NULL); // Cmdline_dualscanlines  -- Change to phreaks options including new targeting code
 cmdline_parm orb_radar("-orbradar", NULL);			// Cmdline_orb_radar
 cmdline_parm rearm_timer_arg("-rearm_timer", NULL);	// Cmdline_rearm_timer
 cmdline_parm targetinfo_arg("-targetinfo", NULL);	// Cmdline_targetinfo  -- Adds ship name/class to right of target box -C
 
--- a/code/hud/hud.cpp
+++ b/code/hud/hud.cpp
@@ -1655,9 +1655,9 @@
 
 	// process asteroid brackets if necessary
 	hud_show_asteroid_brackets();
 
-	// process targetting data around the current target
+	// process targeting data around the current target
 	hud_show_targeting_gauges(frametime);
 
 	// process brackets and distance to remote detonate missile
 	hud_process_remote_detonate_missile();
--- a/code/hud/hudtarget.cpp
+++ b/code/hud/hudtarget.cpp
@@ -46,9 +46,9 @@
 #include "graphics/font.h"
 #include "network/multiutil.h"
 #include "model/model.h"
 
-// If any of these bits in the ship->flags are set, ignore this ship when targetting
+// If any of these bits in the ship->flags are set, ignore this ship when targeting
 int TARGET_SHIP_IGNORE_FLAGS = (SF_EXPLODED|SF_DEPART_WARP|SF_DYING|SF_ARRIVING_STAGE_1|SF_HIDDEN_FROM_SENSORS);
 
 // Global values for the target bracket width and height, used for debugging
 int Hud_target_w, Hud_target_h;
@@ -1282,10 +1282,10 @@
 /// \param target_filters               Applies a bit filter to exclude certain
 ///                                     classes of objects from being targeted.
 ///                                     Defaults to (SIF_CARGO | SIF_NAVBUOY)
 ///                                        
-/// \returns         The next object to target if targetting was successful. 
-///                  Returns NULL if targetting was unsuccessful.
+/// \returns         The next object to target if targeting was successful. 
+///                  Returns NULL if targeting was unsuccessful.
 static object* select_next_target_by_distance( const bool targeting_from_closest_to_farthest, const int valid_team_mask, const int attacked_object_number = -1, const int target_filters = (SIF_CARGO | SIF_NAVBUOY)) {
 	object *minimum_object_ptr, *maximum_object_ptr, *nearest_object_ptr;
 	minimum_object_ptr = maximum_object_ptr = nearest_object_ptr = NULL;
 	float current_distance = hud_find_target_distance(&Objects[Player_ai->target_objnum], Player_obj);
@@ -1988,9 +1988,9 @@
 	}
 }
 
 
-// Given that object 'targeter' is targetting object 'targetee', 
+// Given that object 'targeter' is targeting object 'targetee', 
 // how far are they?   This uses the point closest to the targeter
 // object on the targetee's bounding box.  So if targeter is inside
 // targtee's bounding box, the distance is 0.
 float hud_find_target_distance( object *targetee, object *targeter )
@@ -2139,9 +2139,9 @@
 			}
 		}
 	}
 
-	// If no turret is attacking, check if objp is actually targetting attacked_objnum
+	// If no turret is attacking, check if objp is actually targeting attacked_objnum
 	// don't bail if targeting is for player
 	if ( !targeting_player && !turret_is_attacking ) {
 		ai_info *aip = &Ai_info[esct->shipp->ai_index];
 
@@ -3850,9 +3850,9 @@
 
 	// first render the current target the player has selected.
 	renderLeadCurrentTarget();
 
-	// if extra targetting info is enabled, render lead indicators for objects in the target display list.
+	// if extra targeting info is enabled, render lead indicators for objects in the target display list.
 	for(size_t i = 0; i < target_display_list.size(); i++) {
 		if ( (target_display_list[i].flags & TARGET_DISPLAY_LEAD) && target_display_list[i].objp ) {
 
 			// set the color
--- a/code/network/multimsgs.cpp
+++ b/code/network/multimsgs.cpp
@@ -2810,9 +2810,9 @@
 			if (objp->type == OBJ_SHIP) {
 				ship_actually_depart(objp->instance, s_method); 
 			}
 			else {
-				nprintf(("network", "Can not proces ship depart packed. Object with net signature %d is not a ship!\n", signature ));	
+				nprintf(("network", "Can not process ship depart packed. Object with net signature %d is not a ship!\n", signature ));	
 				return;
 			}
 			break;
 
@@ -4348,9 +4348,9 @@
 	}
 
 	// if this player is not allowed to do messaging, quit here
 	if( !multi_can_message(&Net_players[player_num]) ){
-		nprintf(("Network","Recieved player order packet from player not allowed to give orders!!\n"));
+		nprintf(("Network","Received player order packet from player not allowed to give orders!!\n"));
 		return;
 	}
 
 	// check to see if the type of order is a reinforcement call.  If so, intercept it, and
--- a/code/ship/ship.h
+++ b/code/ship/ship.h
@@ -490,9 +490,9 @@
 #define SF2_NO_THRUSTERS					(1<<23)		// The E - Thrusters on this ship are not rendered.
 #define SF2_SHIP_LOCKED						(1<<24)		// Karajorma - Prevents the player from changing the ship class on loadout screen
 #define SF2_WEAPONS_LOCKED					(1<<25)		// Karajorma - Prevents the player from changing the weapons on the ship on the loadout screen
 
-// If any of these bits in the ship->flags are set, ignore this ship when targetting
+// If any of these bits in the ship->flags are set, ignore this ship when targeting
 extern int TARGET_SHIP_IGNORE_FLAGS;
 
 #define MAX_DAMAGE_SLOTS	32
 #define MAX_SHIP_ARCS		2		// How many "arcs" can be active at once... Must be less than MAX_ARC_EFFECTS in model.h. 
--- a/code/weapon/weapons.cpp
+++ b/code/weapon/weapons.cpp
@@ -2405,9 +2405,9 @@
 						wip->particle_spewers[spew_index].particle_spew_type = PSPEW_PLUME;
 					} else {
 						wip->particle_spewers[spew_index].particle_spew_type = PSPEW_DEFAULT;
 					}
-				// for compatability with existing tables that dont have a type tag
+				// for compatability with existing tables that don't have a type tag
 				} else if (wip->particle_spewers[spew_index].particle_spew_type == PSPEW_NONE) { // make sure the ommission of type wanst to edit an existing entry
 					wip->particle_spewers[spew_index].particle_spew_type = PSPEW_DEFAULT;
 				}
 
@@ -6343,9 +6343,9 @@
 				// reset the timestamp
 				wp->particle_spew_time[psi] = timestamp(wip->particle_spewers[0].particle_spew_time);
 
 				// turn normals and origins to world space if we need to
-				if (!vm_vec_same(&wip->particle_spewers[psi].particle_spew_offset, &vmd_zero_vector)) {	// dont xform unused vectors
+				if (!vm_vec_same(&wip->particle_spewers[psi].particle_spew_offset, &vmd_zero_vector)) {	// don't xform unused vectors
 					vm_vec_unrotate(&spawn_pos, &wip->particle_spewers[psi].particle_spew_offset, &obj->orient);
 				} else {
 					spawn_pos = vmd_zero_vector;
 				}
@@ -6458,9 +6458,9 @@
 						// create a random unit vector and scale it
 						vm_vec_rand_vec_quick(&input_vel);
 						vm_vec_scale(&input_vel, wip->particle_spewers[psi].particle_spew_scale);
 						
-						if (wip->particle_spewers[psi].particle_spew_z_scale != 1.0f) {	// dont do the extra math for spherical effect
+						if (wip->particle_spewers[psi].particle_spew_z_scale != 1.0f) {	// don't do the extra math for spherical effect
 							temp_vel = input_vel;
 							temp_vel.xyz.z *= wip->particle_spewers[psi].particle_spew_z_scale;	// for an oviod particle effect to better combine with laser effects
 							vm_vec_unrotate(&input_vel, &temp_vel, &obj->orient);				// so it has to be rotated
 						}
--- a/code/freespace2/freespace.cpp
+++ b/code/freespace2/freespace.cpp
@@ -2509,9 +2509,9 @@
 
 		if (g3_in_frame() == 0) {
 			// Ensure that the bars are black
 			gr_set_color(0,0,0);
-			gr_set_bitmap(0); // Valathil - Dont ask me why this has to be here but otherwise the black bars dont draw
+			gr_set_bitmap(0); // Valathil - Don't ask me why this has to be here but otherwise the black bars don't draw
 			gr_rect(0, 0, gr_screen.max_w, yborder, false);
 			gr_rect(0, gr_screen.max_h-yborder, gr_screen.max_w, yborder, false);
 		} else {
 			//	Numeric constants encouraged by J "pig farmer" S, who shall remain semi-anonymous.
@@ -4248,9 +4248,9 @@
 
 		if (g3_in_frame() == 0) {
 			//Set rectangles
 			gr_set_color(0,0,0);
-			gr_set_bitmap(0); // Valathil - Dont ask me why this has to be here but otherwise the black bars dont draw
+			gr_set_bitmap(0); // Valathil - Don't ask me why this has to be here but otherwise the black bars don't draw
 			gr_rect(0, 0, gr_screen.max_w, yborder, false);
 			gr_rect(0, gr_screen.max_h-yborder, gr_screen.max_w, yborder, false);
 		} else {
 			//Set clipping
@@ -4263,9 +4263,9 @@
 		int yborder = gr_screen.max_h/CUTSCENE_BAR_DIVISOR;
 
 		if (g3_in_frame() == 0) {
 			gr_set_color(0,0,0);
-			gr_set_bitmap(0); // Valathil - Dont ask me why this has to be here but otherwise the black bars dont draw
+			gr_set_bitmap(0); // Valathil - Don't ask me why this has to be here but otherwise the black bars don't draw
 			gr_rect(0, 0, gr_screen.max_w, yborder, false);
 			gr_rect(0, gr_screen.max_h-yborder, gr_screen.max_w, yborder, false);
 		} else {
 			gr_reset_clip();
--- a/code/missionui/missionscreencommon.cpp
+++ b/code/missionui/missionscreencommon.cpp
@@ -1678,9 +1678,9 @@
 			g3_draw_htl_line(&start,&stop);
 		}
 		g3_done_instance(true);
 
-		gr_zbuffer_set(GR_ZBUFF_NONE); // Turn of Depthbuffer so we dont get gridlines over the ship or a disappearing scanline 
+		gr_zbuffer_set(GR_ZBUFF_NONE); // Turn of Depthbuffer so we don't get gridlines over the ship or a disappearing scanline 
 		Glowpoint_use_depth_buffer = false; // Since we don't have one
 		if (time >= 0.5f) { // Phase 1 onward draw the grid
 			int i;
 			start.xyz.y = -offset;
--- a/code/sound/ds.cpp
+++ b/code/sound/ds.cpp
@@ -300,9 +300,9 @@
 				ogg_int64_t pcm_total_size = ov_pcm_total(ovf, -1);
 				if (pcm_total_size > 0) {
 					*dest_size = (uint)(pcm_total_size * (*header)->nBlockAlign);
 				} else {
-					nprintf(("Sound", "SOUND ==> Size returned for this file is invalid. Please reencode the file, as it will not work correctly.\n"));
+					nprintf(("Sound", "SOUND ==> Size returned for this file is invalid. Please re-encode the file, as it will not work correctly.\n"));
 					return -1;
 				}
 			} else {
 				Assert( 0 );
--- a/lua/lstate.h
+++ b/lua/lstate.h
@@ -42,9 +42,9 @@
 } stringtable;
 
 
 /*
-** informations about a call
+** information about a call
 */
 typedef struct CallInfo {
   StkId base;  /* base for this function */
   StkId func;  /* function index in the stack */
spelling[trunk].patch (26,295 bytes)   

onlyjob

2013-01-13 08:19

reporter   ~0014647

Apologies for messing up with ship.cpp. I'll be more careful.

Please find revised patch for trunk attached. I hope it's better. Thanks.

Goober5000

2013-01-13 09:11

administrator   ~0014648

It's not ship.cpp that's the problem, it's the fact that "dont collide invisible" is actually a flag that is parsed from a file. Don't worry; overall it's a good patch.

Unfortunately, this one was rejected again. I think I see why; you seem to have two separate folder structures under "a" and "b". Fortunately, by editing in Notepad, I was able to convert it so that it patched successfully.

Related Changesets

fs2open: trunk r9503

2013-01-13 04:50

Goober5000


Ported: N/A

Details Diff
onlyjob's spelling fixes, per Mantis 0002777 Affected Issues
0002777
mod - /trunk/fs2_open/code/ai/aiturret.cpp Diff File
mod - /trunk/fs2_open/code/autopilot/autopilot.cpp Diff File
mod - /trunk/fs2_open/code/autopilot/autopilot.h Diff File
mod - /trunk/fs2_open/code/cmdline/cmdline.cpp Diff File
mod - /trunk/fs2_open/code/freespace2/freespace.cpp Diff File
mod - /trunk/fs2_open/code/fs2netd/fs2netd_client.cpp Diff File
mod - /trunk/fs2_open/code/hud/hud.cpp Diff File
mod - /trunk/fs2_open/code/hud/hudtarget.cpp Diff File
mod - /trunk/fs2_open/code/localization/localize.cpp Diff File
mod - /trunk/fs2_open/code/missionui/missionscreencommon.cpp Diff File
mod - /trunk/fs2_open/code/network/multimsgs.cpp Diff File
mod - /trunk/fs2_open/code/network/psnet2.cpp Diff File
mod - /trunk/fs2_open/code/object/objectsnd.cpp Diff File
mod - /trunk/fs2_open/code/parse/lua.cpp Diff File
mod - /trunk/fs2_open/code/parse/sexp.cpp Diff File
mod - /trunk/fs2_open/code/ship/ship.h Diff File
mod - /trunk/fs2_open/code/sound/ds.cpp Diff File
mod - /trunk/fs2_open/code/weapon/weapons.cpp Diff File
mod - /trunk/fs2_open/lua/lstate.h Diff File

Issue History

Date Modified Username Field Change
2013-01-10 05:30 onlyjob New Issue
2013-01-10 05:30 onlyjob Status new => assigned
2013-01-10 05:30 onlyjob Assigned To => chief1983
2013-01-10 05:30 onlyjob File Added: spelling.patch
2013-01-10 20:08 Eli2 Note Added: 0014625
2013-01-10 20:08 Eli2 Note Edited: 0014625
2013-01-10 20:34 chief1983 Note Added: 0014627
2013-01-10 20:50 niffiwan Status assigned => code review
2013-01-12 22:06 Goober5000 Note Added: 0014639
2013-01-12 23:58 chief1983 Note Added: 0014643
2013-01-13 08:17 onlyjob File Added: spelling[trunk].patch
2013-01-13 08:19 onlyjob Note Added: 0014647
2013-01-13 09:11 Goober5000 Note Added: 0014648
2013-01-13 09:13 Goober5000 Changeset attached => fs2open trunk r9503
2013-01-13 09:13 Goober5000 Assigned To chief1983 =>
2013-01-13 09:13 Goober5000 Status code review => resolved
2013-01-13 09:13 Goober5000 Resolution open => fixed
--- a/code/object/objectsnd.cpp
+++ b/code/object/objectsnd.cpp
@@ -31,9 +31,9 @@
 //  int ds3d_update_buffer(int, float, float, vec3d *, vec3d *);
 // --end hack--
 
 
 // Persistant sounds for objects (pointer to obj_snd is in object struct)
 typedef struct _obj_snd {
 	_obj_snd	*next, *prev;
 	int		objnum;			// object index of object that contains this sound
 	int		id;				// Index into Snds[] array
@@ -46,9 +46,9 @@
 	vec3d	offset;			// offset from the center of the object where the sound lives
 	ship_subsys *ss;		//Associated subsystem
 } obj_snd;
 
-#define VOL_PAN_UPDATE			50						// time in ms to update a persistant sound vol/pan
+#define VOL_PAN_UPDATE			50						// time in ms to update a persistent sound vol/pan
 #define MIN_PERSISTANT_VOL		0.10f
 #define MIN_FORWARD_SPEED		5
 #define SPEED_SOUND				600.0f				// speed of sound in FreeSpace
 
@@ -90,12 +90,12 @@
 
 // ---------------------------------------------------------------------------------------
 // dcf_objsnd()
 //
 // Debug console function for object linked persistant sounds
 //
 //XSTR:OFF
-DCF(objsnd, "Persistant sound stuff" )
+DCF(objsnd, "Persistent sound stuff" )
 {
 	char		buf1[16], buf2[64];
 	obj_snd	*osp;
 
@@ -182,9 +182,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_init()
 //
 // Called once at level start to initialize the persistant object sound system
 //
 void obj_snd_level_init()
 {
 	int i;
@@ -211,9 +211,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_stop()
 //
 // Stop a persistant sound from playing.
 //
 // parameters:  objp			=> pointer to object that sound is to be stopped for
 //
 //
@@ -284,9 +284,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_stop_all()
 //
 // Stop all object-linked persistant sounds from playing
 //
 //
 void obj_snd_stop_all()
 {
@@ -447,9 +447,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_do_frame()
 //
 // Called once per frame to process the persistant sound objects
 //
 void obj_snd_do_frame()
 {
 	float				closest_dist, distance, speed_vol_multiplier, rot_vol_mult, percent_max, alive_vol_mult;
@@ -676,15 +676,15 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_assign()
 //
 // Assign a persistant sound to an object.
 //
 // parameters:  objnum		=> index of object that sound is being assigned to
 //              i				=> Index into Snds[] array
 //					 fname		=> filename of sound to play ( so DS3D can load the sound )
 //
 // returns:     -1			=> sound could not be assigned (possible, since only MAX_OBJECT_SOUNDS persistant
 //										sound can be assigned per object).  
 //               >= 0			=> sound was successfully assigned
 //
 int obj_snd_assign(int objnum, int sndnum, vec3d *pos, int main, int flags, ship_subsys *associated_sub)
@@ -759,9 +759,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_delete()
 //
 // Remove a persistant sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
 //				index		=> index of sound in objsnd_num
 //
@@ -789,9 +789,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_delete_type()
 //
 // Remove every similar persistant sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
 //				sndnum		=> index of sound that we're trying to completely get rid of
 //								-1 to delete all persistent sounds on ship.
@@ -831,9 +831,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_delete_all()
 //
 // Remove all persistant sounds
 //
 void obj_snd_delete_all()
 {
 	int idx;
@@ -848,9 +848,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_close()
 //
 // Called once at game close to de-initialize the persistant object sound system
 //
 void obj_snd_level_close()
 {
@@ -31,9 +31,9 @@
 
 
-// Persistant sounds for objects (pointer to obj_snd is in object struct)
+// Persistent sounds for objects (pointer to obj_snd is in object struct)
 typedef struct _obj_snd {
 	_obj_snd	*next, *prev;
@@ -90,12 +90,12 @@
 // dcf_objsnd()
 //
-// Debug console function for object linked persistant sounds
+// Debug console function for object linked persistent sounds
 //
 //XSTR:OFF
@@ -182,9 +182,9 @@
 // obj_snd_init()
 //
-// Called once at level start to initialize the persistant object sound system
+// Called once at level start to initialize the persistent object sound system
 //
 void obj_snd_level_init()
@@ -211,9 +211,9 @@
 // obj_snd_stop()
 //
-// Stop a persistant sound from playing.
+// Stop a persistent sound from playing.
 //
 // parameters:  objp			=> pointer to object that sound is to be stopped for
@@ -284,9 +284,9 @@
 // obj_snd_stop_all()
 //
-// Stop all object-linked persistant sounds from playing
+// Stop all object-linked persistent sounds from playing
 //
 //
@@ -447,9 +447,9 @@
 // obj_snd_do_frame()
 //
-// Called once per frame to process the persistant sound objects
+// Called once per frame to process the persistent sound objects
 //
 void obj_snd_do_frame()
@@ -676,15 +676,15 @@
 // obj_snd_assign()
 //
-// Assign a persistant sound to an object.
+// Assign a persistent sound to an object.
 //
 // parameters:  objnum		=> index of object that sound is being assigned to
@@ -676,15 +676,15 @@
 //					 fname		=> filename of sound to play ( so DS3D can load the sound )
 //
-// returns:     -1			=> sound could not be assigned (possible, since only MAX_OBJECT_SOUNDS persistant
+// returns:     -1			=> sound could not be assigned (possible, since only MAX_OBJECT_SOUNDS persistent
 //										sound can be assigned per object).  
 //               >= 0			=> sound was successfully assigned
@@ -759,9 +759,9 @@
 // obj_snd_delete()
 //
-// Remove a persistant sound that has been assigned to an object.
+// Remove a persistent sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
@@ -789,9 +789,9 @@
 // obj_snd_delete_type()
 //
-// Remove every similar persistant sound that has been assigned to an object.
+// Remove every similar persistent sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
@@ -831,9 +831,9 @@
 // obj_snd_delete_all()
 //
-// Remove all persistant sounds
+// Remove all persistent sounds
 //
 void obj_snd_delete_all()
@@ -848,9 +848,9 @@
 // obj_snd_close()
 //
-// Called once at game close to de-initialize the persistant object sound system
+// Called once at game close to de-initialize the persistent object sound system
 //
 void obj_snd_level_close()
 	if ( !Obj_snd_level_inited ) {
--- a/code/parse/sexp.cpp
+++ b/code/parse/sexp.cpp
@@ -11168,9 +11168,9 @@
 #ifndef NDEBUG
 	// Don't give warning for large ships (cruiser on up) 
 	if (! (Ship_info[Ships[shipnum2].ship_info_index].flags & (SIF_BIG_SHIP | SIF_HUGE_SHIP)) ) {
 		if ( stricmp(Cargo_names[Ships[shipnum2].cargo1 & CARGO_INDEX_MASK], "nothing") ) {
-			Warning(LOCATION, "Transfering cargo to %s which already\nhas cargo %s.\nCargo will be replaced", Ships[shipnum2].ship_name, Cargo_names[Ships[shipnum2].cargo1 & CARGO_INDEX_MASK] );
+			Warning(LOCATION, "Transferring cargo to %s which already\nhas cargo %s.\nCargo will be replaced", Ships[shipnum2].ship_name, Cargo_names[Ships[shipnum2].cargo1 & CARGO_INDEX_MASK] );
 		}
 	}
 #endif
 	Ships[shipnum2].cargo1 = char((Ships[shipnum1].cargo1 & CARGO_INDEX_MASK) | (Ships[shipnum2].cargo1 & CARGO_NO_DEPLETE));
@@ -12879,9 +12879,9 @@
 	else
 		Warning(LOCATION, "Invalid turret type '%s'!", turret_type);
 }
 
 // Goober5000 - sets the "dont collide invisible" flag on a list of ships
 void sexp_dont_collide_invisible(int n, bool dont_collide)
 {
 	sexp_deal_with_ship_flag(n, true, 0, 0, 0, SF2_DONT_COLLIDE_INVIS, 0, P_SF2_DONT_COLLIDE_INVIS, dont_collide);
 }
@@ -28555,12 +28555,12 @@
 		"Currently, only 1 medal will be allowed to be given per mission.\r\n\r\n"
 		"Takes 1 argument...\r\n"
 		"\t1:\tName of medal to grant to player." },
 
-	{ OP_GOOD_SECONDARY_TIME, "Set prefered secondary weapons\r\n"
-		"\tThis sexpression is used to inform the AI about prefered secondary weapons to "
+	{ OP_GOOD_SECONDARY_TIME, "Set preferred secondary weapons\r\n"
+		"\tThis sexpression is used to inform the AI about preferred secondary weapons to "
 		"fire during combat.  When this expression is evaulated, any AI ships of the given "
-		"team prefer to fire the given weapon at the given ship. (Prefered over other "
+		"team prefer to fire the given weapon at the given ship. (Preferred over other "
 		"secondary weapons)\r\n\r\n"
 		"Takes 4 argument...\r\n"
 		"\t1:\tTeam name which will prefer firing given weapon\r\n"
 		"\t2:\tMaximum number of this type of weapon above team can fire.\r\n"
@@ -28756,14 +28756,14 @@
 		"Takes 1 or more arguments...\r\n"
 		"\t1+:\tName of ships to make invulnerable to weapons." },
 
 	{ OP_SHIP_BOMB_TARGETABLE, "ship-targetable-as-bomb\r\n"
-		"\tCauses the ships listed in this sexpression to be targetable with bomb targetting key.\r\n\r\n"
+		"\tCauses the ships listed in this sexpression to be targetable with bomb targeting key.\r\n\r\n"
 		"Takes 1 or more arguments...\r\n"
 		"\t1+:\tName of ships to make targetable with bomb targeting key." },
 
 	{ OP_SHIP_BOMB_UNTARGETABLE, "ship-untargetable-as-bomb\r\n"
-		"\tCauses the ships listed in this sexpression to not be targetable with bomb targetting key.\r\n\r\n"
+		"\tCauses the ships listed in this sexpression to not be targetable with bomb targeting key.\r\n\r\n"
 		"Takes 1 or more arguments...\r\n"
 		"\t1+:\tName of ships to make nontargetable with bomb targeting key." },
 
 	{ OP_SHIELDS_ON, "shields-on\r\n" //-Sesquipedalian
@@ -29032,16 +29032,16 @@
 		"Takes 1 or more arguments...\r\n"
 		"\tAll:\tList of ships on which to unset the vaporize flag" },
 
 	{ OP_DONT_COLLIDE_INVISIBLE, "don't-collide-invisible\r\n"
-		"\tSets the \"dont collide invisible\" flag on a list of ships.\r\n"
+		"\tSets the \"don't collide invisible\" flag on a list of ships.\r\n"
 		"Takes 1 or more arguments...\r\n"
-		"\tAll:\tList of ships on which to set the \"dont collide invisible\" flag" },
+		"\tAll:\tList of ships on which to set the \"don't collide invisible\" flag" },
 
 	{ OP_COLLIDE_INVISIBLE, "collide-invisible\r\n"
-		"\tUnsets the \"dont collide invisible\" flag on a list of ships.\r\n"
+		"\tUnsets the \"don't collide invisible\" flag on a list of ships.\r\n"
 		"Takes 1 or more arguments...\r\n"
-		"\tAll:\tList of ships on which to unset the \"dont collide invisible\" flag" },
+		"\tAll:\tList of ships on which to unset the \"don't collide invisible\" flag" },
 
 	{ OP_SET_MOBILE, "set-mobile\r\n"
 		"\tAllows the specified ship(s) to move.  Opposite of set-immobile.\r\n"
@@ -12879,9 +12879,9 @@
 }
 
-// Goober5000 - sets the "dont collide invisible" flag on a list of ships
+// Goober5000 - sets the "don't collide invisible" flag on a list of ships
 void sexp_dont_collide_invisible(int n, bool dont_collide)
 {
 		"Takes 1 or more arguments...\r\n"
--- a/code/object/objectsnd.cpp
+++ b/code/object/objectsnd.cpp
@@ -31,9 +31,9 @@
 //  int ds3d_update_buffer(int, float, float, vec3d *, vec3d *);
 // --end hack--
 
 
 // Persistant sounds for objects (pointer to obj_snd is in object struct)
 typedef struct _obj_snd {
 	_obj_snd	*next, *prev;
 	int		objnum;			// object index of object that contains this sound
 	int		id;				// Index into Snds[] array
@@ -46,9 +46,9 @@
 	vec3d	offset;			// offset from the center of the object where the sound lives
 	ship_subsys *ss;		//Associated subsystem
 } obj_snd;
 
-#define VOL_PAN_UPDATE			50						// time in ms to update a persistant sound vol/pan
+#define VOL_PAN_UPDATE			50						// time in ms to update a persistent sound vol/pan
 #define MIN_PERSISTANT_VOL		0.10f
 #define MIN_FORWARD_SPEED		5
 #define SPEED_SOUND				600.0f				// speed of sound in FreeSpace
 
@@ -90,12 +90,12 @@
 
 // ---------------------------------------------------------------------------------------
 // dcf_objsnd()
 //
 // Debug console function for object linked persistant sounds
 //
 //XSTR:OFF
-DCF(objsnd, "Persistant sound stuff" )
+DCF(objsnd, "Persistent sound stuff" )
 {
 	char		buf1[16], buf2[64];
 	obj_snd	*osp;
 
@@ -182,9 +182,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_init()
 //
 // Called once at level start to initialize the persistant object sound system
 //
 void obj_snd_level_init()
 {
 	int i;
@@ -211,9 +211,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_stop()
 //
 // Stop a persistant sound from playing.
 //
 // parameters:  objp			=> pointer to object that sound is to be stopped for
 //
 //
@@ -284,9 +284,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_stop_all()
 //
 // Stop all object-linked persistant sounds from playing
 //
 //
 void obj_snd_stop_all()
 {
@@ -445,9 +445,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_do_frame()
 //
 // Called once per frame to process the persistant sound objects
 //
 void obj_snd_do_frame()
 {
 	float				closest_dist, distance, speed_vol_multiplier, rot_vol_mult, percent_max, alive_vol_mult;
@@ -674,15 +674,15 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_assign()
 //
 // Assign a persistant sound to an object.
 //
 // parameters:  objnum		=> index of object that sound is being assigned to
 //              i				=> Index into Snds[] array
 //					 fname		=> filename of sound to play ( so DS3D can load the sound )
 //
 // returns:     -1			=> sound could not be assigned (possible, since only MAX_OBJECT_SOUNDS persistant
 //										sound can be assigned per object).  
 //               >= 0			=> sound was successfully assigned
 //
 int obj_snd_assign(int objnum, int sndnum, vec3d *pos, int main, int flags, ship_subsys *associated_sub)
@@ -757,9 +757,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_delete()
 //
 // Remove a persistant sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
 //				index		=> index of sound in objsnd_num
 //
@@ -787,9 +787,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_delete_type()
 //
 // Remove every similar persistant sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
 //				sndnum		=> index of sound that we're trying to completely get rid of
 //								-1 to delete all persistent sounds on ship.
@@ -829,9 +829,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_delete_all()
 //
 // Remove all persistant sounds
 //
 void obj_snd_delete_all()
 {
 	int idx;
@@ -846,9 +846,9 @@
 
 // ---------------------------------------------------------------------------------------
 // obj_snd_close()
 //
 // Called once at game close to de-initialize the persistant object sound system
 //
 void obj_snd_level_close()
 {
@@ -31,9 +31,9 @@
 
 
-// Persistant sounds for objects (pointer to obj_snd is in object struct)
+// Persistent sounds for objects (pointer to obj_snd is in object struct)
 typedef struct _obj_snd {
 	_obj_snd	*next, *prev;
@@ -90,12 +90,12 @@
 // dcf_objsnd()
 //
-// Debug console function for object linked persistant sounds
+// Debug console function for object linked persistent sounds
 //
 //XSTR:OFF
@@ -182,9 +182,9 @@
 // obj_snd_init()
 //
-// Called once at level start to initialize the persistant object sound system
+// Called once at level start to initialize the persistent object sound system
 //
 void obj_snd_level_init()
@@ -211,9 +211,9 @@
 // obj_snd_stop()
 //
-// Stop a persistant sound from playing.
+// Stop a persistent sound from playing.
 //
 // parameters:  objp			=> pointer to object that sound is to be stopped for
@@ -284,9 +284,9 @@
 // obj_snd_stop_all()
 //
-// Stop all object-linked persistant sounds from playing
+// Stop all object-linked persistent sounds from playing
 //
 //
@@ -445,9 +445,9 @@
 // obj_snd_do_frame()
 //
-// Called once per frame to process the persistant sound objects
+// Called once per frame to process the persistent sound objects
 //
 void obj_snd_do_frame()
@@ -674,15 +674,15 @@
 // obj_snd_assign()
 //
-// Assign a persistant sound to an object.
+// Assign a persistent sound to an object.
 //
 // parameters:  objnum		=> index of object that sound is being assigned to
@@ -674,15 +674,15 @@
 //					 fname		=> filename of sound to play ( so DS3D can load the sound )
 //
-// returns:     -1			=> sound could not be assigned (possible, since only MAX_OBJECT_SOUNDS persistant
+// returns:     -1			=> sound could not be assigned (possible, since only MAX_OBJECT_SOUNDS persistent
 //										sound can be assigned per object).  
 //               >= 0			=> sound was successfully assigned
@@ -757,9 +757,9 @@
 // obj_snd_delete()
 //
-// Remove a persistant sound that has been assigned to an object.
+// Remove a persistent sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
@@ -787,9 +787,9 @@
 // obj_snd_delete_type()
 //
-// Remove every similar persistant sound that has been assigned to an object.
+// Remove every similar persistent sound that has been assigned to an object.
 //
 // parameters:  objnum		=> index of object that sound is being removed from.
@@ -829,9 +829,9 @@
 // obj_snd_delete_all()
 //
-// Remove all persistant sounds
+// Remove all persistent sounds
 //
 void obj_snd_delete_all()
@@ -846,9 +846,9 @@
 // obj_snd_close()
 //
-// Called once at game close to de-initialize the persistant object sound system
+// Called once at game close to de-initialize the persistent object sound system
 //
 void obj_snd_level_close()
 	if ( !Obj_snd_level_inited ) {
--- a/code/parse/sexp.cpp
+++ b/code/parse/sexp.cpp
@@ -11546,9 +11546,9 @@
 #ifndef NDEBUG
 	// Don't give warning for large ships (cruiser on up) 
 	if (! (Ship_info[Ships[shipnum2].ship_info_index].flags & (SIF_BIG_SHIP | SIF_HUGE_SHIP)) ) {
 		if ( stricmp(Cargo_names[Ships[shipnum2].cargo1 & CARGO_INDEX_MASK], "nothing") ) {
-			Warning(LOCATION, "Transfering cargo to %s which already\nhas cargo %s.\nCargo will be replaced", Ships[shipnum2].ship_name, Cargo_names[Ships[shipnum2].cargo1 & CARGO_INDEX_MASK] );
+			Warning(LOCATION, "Transferring cargo to %s which already\nhas cargo %s.\nCargo will be replaced", Ships[shipnum2].ship_name, Cargo_names[Ships[shipnum2].cargo1 & CARGO_INDEX_MASK] );
 		}
 	}
 #endif
 	Ships[shipnum2].cargo1 = char((Ships[shipnum1].cargo1 & CARGO_INDEX_MASK) | (Ships[shipnum2].cargo1 & CARGO_NO_DEPLETE));
@@ -13686,9 +13686,9 @@
 	else
 		Warning(LOCATION, "Invalid turret type '%s'!", turret_type);
 }
 
 // Goober5000 - sets the "dont collide invisible" flag on a list of ships
 void sexp_dont_collide_invisible(int n, bool dont_collide)
 {
 	sexp_deal_with_ship_flag(n, true, 0, 0, 0, SF2_DONT_COLLIDE_INVIS, 0, P_SF2_DONT_COLLIDE_INVIS, dont_collide);
 }
@@ -29973,12 +29973,12 @@
 		"Currently, only 1 medal will be allowed to be given per mission.\r\n\r\n"
 		"Takes 1 argument...\r\n"
 		"\t1:\tName of medal to grant to player." },
 
-	{ OP_GOOD_SECONDARY_TIME, "Set prefered secondary weapons\r\n"
-		"\tThis sexpression is used to inform the AI about prefered secondary weapons to "
+	{ OP_GOOD_SECONDARY_TIME, "Set preferred secondary weapons\r\n"
+		"\tThis sexpression is used to inform the AI about preferred secondary weapons to "
 		"fire during combat.  When this expression is evaulated, any AI ships of the given "
-		"team prefer to fire the given weapon at the given ship. (Prefered over other "
+		"team prefer to fire the given weapon at the given ship. (Preferred over other "
 		"secondary weapons)\r\n\r\n"
 		"Takes 4 argument...\r\n"
 		"\t1:\tTeam name which will prefer firing given weapon\r\n"
 		"\t2:\tMaximum number of this type of weapon above team can fire.\r\n"
@@ -30182,14 +30182,14 @@
 		"Takes 1 or more arguments...\r\n"
 		"\t1+:\tName of ships to make invulnerable to weapons." },
 
 	{ OP_SHIP_BOMB_TARGETABLE, "ship-targetable-as-bomb\r\n"
-		"\tCauses the ships listed in this sexpression to be targetable with bomb targetting key.\r\n\r\n"
+		"\tCauses the ships listed in this sexpression to be targetable with bomb targeting key.\r\n\r\n"
 		"Takes 1 or more arguments...\r\n"
 		"\t1+:\tName of ships to make targetable with bomb targeting key." },
 
 	{ OP_SHIP_BOMB_UNTARGETABLE, "ship-untargetable-as-bomb\r\n"
-		"\tCauses the ships listed in this sexpression to not be targetable with bomb targetting key.\r\n\r\n"
+		"\tCauses the ships listed in this sexpression to not be targetable with bomb targeting key.\r\n\r\n"
 		"Takes 1 or more arguments...\r\n"
 		"\t1+:\tName of ships to make nontargetable with bomb targeting key." },
 
 	{ OP_SHIELDS_ON, "shields-on\r\n" //-Sesquipedalian
@@ -30458,16 +30458,16 @@
 		"Takes 1 or more arguments...\r\n"
 		"\tAll:\tList of ships on which to unset the vaporize flag" },
 
 	{ OP_DONT_COLLIDE_INVISIBLE, "don't-collide-invisible\r\n"
-		"\tSets the \"dont collide invisible\" flag on a list of ships.\r\n"
+		"\tSets the \"don't collide invisible\" flag on a list of ships.\r\n"
 		"Takes 1 or more arguments...\r\n"
-		"\tAll:\tList of ships on which to set the \"dont collide invisible\" flag" },
+		"\tAll:\tList of ships on which to set the \"don't collide invisible\" flag" },
 
 	{ OP_COLLIDE_INVISIBLE, "collide-invisible\r\n"
-		"\tUnsets the \"dont collide invisible\" flag on a list of ships.\r\n"
+		"\tUnsets the \"don't collide invisible\" flag on a list of ships.\r\n"
 		"Takes 1 or more arguments...\r\n"
-		"\tAll:\tList of ships on which to unset the \"dont collide invisible\" flag" },
+		"\tAll:\tList of ships on which to unset the \"don't collide invisible\" flag" },
 
 	{ OP_SET_MOBILE, "set-mobile\r\n"
 		"\tAllows the specified ship(s) to move.  Opposite of set-immobile.\r\n"
@@ -13686,9 +13686,9 @@
 }
 
-// Goober5000 - sets the "dont collide invisible" flag on a list of ships
+// Goober5000 - sets the "don't collide invisible" flag on a list of ships
 void sexp_dont_collide_invisible(int n, bool dont_collide)
 {
 		"Takes 1 or more arguments...\r\n"